@@ -27,7 +27,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 error_reporting(E_PARSE | E_ERROR);
 if (strpos($opts='^'.implode('_', $_SERVER["argv"]).'$', "--debug") + strpos($opts, "--verbose")) { error_reporting(E_ALL); } 
 
-define("VERSION", "2.2.8");
+define("VERSION", "2.2.9");
 
 // Hard configuration and defaults
 
@@ -2060,9 +2060,9 @@ while (true) {
 		
 		$ns=socket_select($lnset, $write=NULL, $except=NULL, 1);
 		
-		if ($ns) {
+		if ($ns) foreach ($lnset as $lnact) {
 				
-			if ($lnset[0]==$children_sck) {
+			if ($lnact==$children_sck) {
 			
 				while ($msg=socket_read($children_sck, INT_MSGSIZE)) {
 
@@ -2158,7 +2158,7 @@ while (true) {
 
 			} else {
 
-				$sock=$lnset[0];
+				$sock=$lnact;
 				$lport=$lports[$sock];
 
 				if ((($active_servers<$conf["global"]["maxservers"][0]) || (!$conf["global"]["maxservers"][0])) && (is_resource($msgsock=@socket_accept($sock)))) {
